@@ -1,5 +1,5 @@
 /*
- * Copyright (C)2021-2024 D. R. Commander.  All Rights Reserved.
+ * Copyright (C)2021-2025 D. R. Commander.  All Rights Reserved.
  *
  * Redistribution and use in source and binary forms, with or without
  * modification, are permitted provided that the following conditions are met:
@@ -26,7 +26,7 @@
  * POSSIBILITY OF SUCH DAMAGE.
  */
 
-#include <turbojpeg.h>
+#include "../src/turbojpeg.h"
 #include <stdio.h>
 #include <stdlib.h>
 #include <stdint.h>
@@ -48,7 +48,7 @@ extern "C" int LLVMFuzzerTestOneInput(const uint8_t *data, size_t size)
 {
   tjhandle handle = NULL;
   unsigned char *srcBuf = NULL, *dstBuf = NULL, *yuvBuf = NULL;
-  int width = 0, height = 0, fd = -1, i, ti;
+  int width = 0, height = 0, fd = -1, ti;
   char filename[FILENAME_MAX] = { 0 };
   struct test tests[NUMTESTS] = {
     { TJPF_XBGR, TJSAMP_444, 100 },
@@ -67,8 +67,8 @@ extern "C" int LLVMFuzzerTestOneInput(const uint8_t *data, size_t size)
     goto bailout;
 
   for (ti = 0; ti < NUMTESTS; ti++) {
-    int sum = 0, pf = tests[ti].pf;
-    size_t dstSize = 0, maxBufSize;
+    int pf = tests[ti].pf;
+    size_t dstSize = 0, maxBufSize, i, sum = 0;
 
     /* Test non-default compression options on specific iterations. */
     tj3Set(handle, TJPARAM_BOTTOMUP, ti == 0);
@@ -86,8 +86,8 @@ extern "C" int LLVMFuzzerTestOneInput(const uint8_t *data, size_t size)
                                 &pf)) == NULL)
       continue;
 
-    maxBufSize = tj3JPEGBufSize(width, height, tests[ti].subsamp);
-    if ((dstBuf = (unsigned char *)tj3Alloc(maxBufSize)) == NULL)
+    dstSize = maxBufSize = tj3JPEGBufSize(width, height, tests[ti].subsamp);
+    if ((dstBuf = (unsigned char *)tj3Alloc(dstSize)) == NULL)
       goto bailout;
     if ((yuvBuf =
          (unsigned char *)malloc(tj3YUVBufSize(width, 1, height,
